==> digikam-trinity_3.5.13.2.orig.tar.xz: digikam-trinity-3.5.13.2/digikam/libs/widgets/common/statusled.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2008-02-15
 * Description : a led indicator.
 * 
 * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

// TQt includes.

#include <tqpixmap.h>
#include <tqstring.h>

// KDE includes.

#include <kglobalsettings.h>
#include <kstandarddirs.h>

// Local includes.

#include "statusled.h"
#include "statusled.moc"

namespace Digikam
{

StatusLed::StatusLed(TQWidget *parent)
         : TQLabel(parent)
{
    setLedColor(Gray);
    setFocusPolicy(TQ_NoFocus);
}

StatusLed::~StatusLed()
{
}

void StatusLed::setLedColor(LedColor color)
{
    m_color = color;

    TQString file;
    switch(m_color)
    {
        case Green:
            file = TQString("indicator-green");
            break;

        case Red:
            file = TQString("indicator-red");
            break;

        default:
            file = TQString("indicator-gray");
            break;
    }

    KGlobal::dirs()->addResourceType(file.ascii(), KGlobal::dirs()->kde_default("data") + "digikam/data");
    TQString directory = KGlobal::dirs()->findResourceDir(file.ascii(), file + TQString(".png"));
    setPixmap(TQPixmap(directory + file + TQString(".png")));
}

StatusLed::LedColor StatusLed::ledColor() const
{
    return m_color;
}

}  // namespace Digikam

==> digikam-trinity_14.0.11.orig.tar.xz: digikam-trinity-14.0.11/digikam/libs/widgets/common/statusled.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2008-02-15
 * Description : a led indicator.
 * 
 * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

// TQt includes.

#include <tqpixmap.h>
#include <tqstring.h>

// KDE includes.

#include <tdeglobalsettings.h>
#include <kstandarddirs.h>

// Local includes.

#include "statusled.h"
#include "statusled.moc"

namespace Digikam
{

StatusLed::StatusLed(TQWidget *parent)
         : TQLabel(parent)
{
    setLedColor(Gray);
    setFocusPolicy(TQ_NoFocus);
}

StatusLed::~StatusLed()
{
}

void StatusLed::setLedColor(LedColor color)
{
    m_color = color;

    TQString file;
    switch(m_color)
    {
        case Green:
            file = TQString("indicator-green");
            break;

        case Red:
            file = TQString("indicator-red");
            break;

        default:
            file = TQString("indicator-gray");
            break;
    }

    TDEGlobal::dirs()->addResourceType(file.ascii(), TDEGlobal::dirs()->kde_default("data") + "digikam/data");
    TQString directory = TDEGlobal::dirs()->findResourceDir(file.ascii(), file + TQString(".png"));
    setPixmap(TQPixmap(directory + file + TQString(".png")));
}

StatusLed::LedColor StatusLed::ledColor() const
{
    return m_color;
}

}  // namespace Digikam
